This dataset, MERSKorea2015_list, is a list containing two data frames with information collected during the first weeks of the Middle East respiratory syndrome (MERS-CoV) outbreak in South Korea in 2015. The data was initially gathered by the Epidemic Intelligence group at the European Centre for Disease Prevention and Control (ECDC).
data(MERSKorea2015_list)A list of 2 elements:
A data frame with 162 observations and 15 variables:
Case identifier (character)
Age of the individual (integer)
Age class of the individual (character)
Sex of the individual (factor with 2 levels)
Place of infection (factor with 2 levels)
Reporting country (factor with 2 levels)
Location or hospital (factor with 13 levels)
Date of symptom onset (Date)
Date of case report (Date)
Week of report (factor with 5 levels)
Start date of exposure (Date)
End date of exposure (Date)
Date of diagnosis (Date)
Outcome of the case (factor with 2 levels)
Date of death, if applicable (Date)
A data frame with 98 observations and 4 variables:
ID of the source case (character)
ID of the contact case (character)
Type of exposure (factor with 5 levels)
Difference in days between onset dates (integer)
The dataset name has been kept as 'MERSKorea2015_list' to avoid confusion with other datasets in the R ecosystem. This naming convention helps distinguish this dataset as part of the SouthKoreAPIs package and assists users in identifying its specific characteristics. The suffix 'list' indicates that the object is a list containing multiple related data frames. The original content has not been modified in any way.